powered by
is.PosteriorAdj is a general test of an object being interpretable as a PosteriorAdj object.
is.PosteriorAdj
PosteriorAdj
is.PosteriorAdj(x)
object to be tested.
The PosteriorAdj class is defined as the posterior adjacency object that results from the PosteriorAdj function.