powered by
is.STBDwDM is a general test of an object being interpretable as a STBDwDM object.
is.STBDwDM
STBDwDM
is.STBDwDM(x)
object to be tested.
The STBDwDM class is defined as the regression object that results from the STBDwDM regression function.