Predicts future observations from the STBDwDM model.
# S3 method for STBDwDM
predict(object, NewTimes, ...)predict.STBDwDM returns a list containing the following objects.
MuTauAlphaA list containing three matrices, mu,
tau and alpha. Each matrix is dimension NKeep x s, where
s is the number of new time points. Each matrix contains posterior
samples obtained by Bayesian krigging.
YA list containing s posterior predictive distribution
matrices. Each matrix is dimension NKeep x s, where s
is the number of new time points. Each matrix is obtained through Bayesian krigging.
a STBDwDM model object for which predictions
are desired from.
a numeric vector including desired time(s) points for prediction.
other arguments.
Samuel I. Berchuck
predict.STBDwDM uses Bayesian krigging to predict vectors at future
time points. The function returns the krigged observed outcomes along with the
observational level parameters (mu, tau, and alpha).